@@ -1,4 +1,4 @@
-from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
+from ocp_resources.resource import NamespacedResource
 
 
 class CSIStorageCapacity(NamespacedResource):
@@ -32,11 +32,11 @@ class CSIStorageCapacity(NamespacedResource):
         self.storage_class_name = storage_class_name
         self.maximum_volume_size = maximum_volume_size
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
         if not self.yaml_file:
             if not self.storage_class_name:
-                raise MissingRequiredArgumentError(argument="storage_class_name")
+                raise ValueError("yaml_file or parameter 'storage_class_name' is required.")
             self.res.update({
                 "storageClassName": self.storage_class_name,
             })
